Structs
- AssociativePositionalList is a positional container in which each value is associated with an index, starting at 0 for the first element. Values can be
inserted andremoved at any index. The value at any index can be accessed withget. But unlike other list containers such asVec, the association between index and value is reversible, and the index for a value may be determined usingfind. - This is an iterator over elements in an AssociativePositionalList